@@ -980,7 +980,15 @@ TABULAR_HEADER = ['seq_id',
                   'd_gene',
                   'j_full',
                   'j_gene',
+                  'junction_aa',
+                  'junction_nt',
                   'cdr3_length',
+                  'fr1_aa',
+                  'fr2_aa',
+                  'fr3_aa',
+                  'fr4_aa',
+                  'cdr1_aa',
+                  'cdr2_aa',
                   'cdr3_nt',
                   'cdr3_aa',
                   'v_start',
